**********************
Nengo GUI contributors
**********************

This is a list of people who have contributed to Nengo GUI.
Note that this is not the list of copyright holders;
Applied Brain Research Inc. holds the copyright to
all Nengo GUI code, except for code that is used under
various licenses, as described in the ``LICENSE.rst`` file.

By adding your name to this file, you are agreeing
to the Contributor Assignment Agreement found in
the ``LICENSE.rst`` file. If you agree, then add yourself
to the file like so::

  - Name <email address>

Please keep this list sorted alphabetically by first name.

- Aaron Voelker <arvoelke@gmail.com>
- Andreas Stöckel <andreas.stoeckel@gmail.com>
- Andrew Mundy <andrew.mundy@manchester.ac.uk>
- Brent Komer <brent.komer@gmail.com>
- Chris Eliasmith <celiasmith@uwaterloo.ca>
- Christopher Chan <c88chan@uwaterloo.ca>
- Eric Hunsberger <erichuns@gmail.com>
- Jan Gosmann <jan@hyper-world.de>
- Petrut Bogdan <petrutantoniu8@gmail.com>
- Rees Simmons <rsimmons@uwaterloo.ca>
- Sean Aubin <seanaubin@gmail.com>
- Sugandha Sharma <sugandha974@gmail.com>
- Terry Stewart <terry.stewart@gmail.com>
- Travis DeWolf <travis.dewolf@gmail.com>
- Trevor Bekolay <tbekolay@gmail.com>
- Xuan Choo <fxchoo@gmail.com>
- Ziying Zhang <zy8zhang@uwaterloo.ca>
